Parker

Struct Parker 

pub(crate) struct Parker {
    inner: Arc<Inner>,
}

Fields

inner: Arc<Inner>

Implementations

Source

impl Parker

pub(crate) fn new(driver: Driver) -> Parker

pub(crate) fn unpark(&self) -> Unparker

pub(crate) fn park(&mut self, handle: &Handle) -> HadDriver

pub(crate) fn park_timeout( &mut self, handle: &Handle, duration: Duration, ) -> HadDriver

Parks the current thread for up to duration.

This function tries to acquire the driver lock. If it succeeds, it parks using the driver. Otherwise, it fails back to using a condvar, unless the duration is zero, in which case it returns immediately.

pub(crate) fn shutdown(&mut self, handle: &Handle)